import json
import logging
import os
from typing import Annotated

from fastapi import APIRouter, Depends

from FormatParameters import FormatParameters
from list_dir import list_dir
from authentication import get_current_active_user
from models import User
from responses import Styles, Formats

router = APIRouter()

@router.get("/styles/")
async def get_styles(current_user: Annotated[User, Depends(get_current_active_user)]):
    styles = Styles(styles=list_dir(f"{os.getcwd()}/styles"))
    return styles

@router.get("/formats/{style}/")
async def get_formats(style: str, current_user: Annotated[User, Depends(get_current_active_user)]):
    formats = Formats(formats=list_dir(f"{os.getcwd()}/styles/{style}/"))
    return formats

@router.get("/format_parameters/{style}/{format}/")
async def get_format_parameters(style: str, format: str, current_user: Annotated[User, Depends(get_current_active_user)]):
    # open styles/format_parameters.json as a dictionary
    with open(f"{os.getcwd()}/styles/{style}/format_parameters.json", "r") as f:
        format_data = json.load(f).get(format)
        logging.info(str(format_data))
        # load data from format_data into the FormatParameters object
        parameters = FormatParameters(**format_data)
    return parameters